==> util-1.0.3-sources.jar: android/library/util/http/HttpBuildUtil.java <==
package android.library.util.http;

import okhttp3.*;

import java.io.File;
import java.util.Map;

public class HttpBuildUtil {
    private static final MediaType MEDIA_TYPE_ATTACH = MediaType.parse("application/octet-stream;charset=utf-8");
    private static final MediaType MEDIA_TYPE_JSON = MediaType.parse("application/json;charset=utf-8");

    /**
     * 构建一个Get Request
     *
     * @param r HttpBuilder
     * @return Request
     */
    public static Request createGetRequest(HttpBuilder r) {
        Request.Builder builder = buildRequestBuilder(r.getHeaders(), r.getCacheControl(), r.getTag());
        return builder.url(r.getUrl())
                .get()
                .build();
    }

    /**
     * 构建一个Post From Request
     *
     * @param r HttpBuilder
     * @return Request
     */
    public static Request createPostFromRequest(HttpBuilder r) {
        Request.Builder builder = buildRequestBuilder(r.getHeaders(), r.getCacheControl(), r.getTag());
        return builder.url(r.getUrl())
                .post(r.getRequestBody())
                .build();
    }

    /**
     * 构建一个Post JSON Request
     *
     * @param r HttpBuilder
     * @return Request
     */
    public static Request createPostJSONRequest(HttpBuilder r) {
        Request.Builder builder = buildRequestBuilder(r.getHeaders(), r.getCacheControl(), r.getTag());
        return builder.url(r.getUrl())
                .post(RequestBody.create(MEDIA_TYPE_JSON, r.getJsonParams()))
                .build();
    }

    /**
     * 构建一个没有设置请求方法的 Request.Builder
     *
     * @param headers      请求头
     * @param cacheControl 缓存控制
     * @param tag          tag
     * @return Request.Builder对象
     */
    public static Request.Builder buildRequestBuilder(Headers headers, CacheControl cacheControl, Object tag) {
        Request.Builder builder = new Request.Builder();
        builder.tag(tag);
        if (headers != null) {
            builder.headers(headers);
        }
        if (cacheControl != null) {
            builder.cacheControl(cacheControl);
        }
        return builder;
    }

    /**
     * 构建一个表单
     *
     * @param map map参数集合
     * @return RequestBody
     */
    public static <K, V> RequestBody buildFormRequestBody(Map<K, V> map) {
        FormBody.Builder builder = new FormBody.Builder();
        //遍历参数
        if (map != null) {
            for (Map.Entry<K, V> entry : map.entrySet()) {
                builder.add(entry.getKey().toString(), entry.getValue().toString());
            }
        }
        return builder.build();
    }

    /**
     * 构建一个表单(带文件)
     *
     * @param map     map参数集合
     * @param fileMap map文件集合
     * @return RequestBody
     */
    public static RequestBody buildFormRequestBody(Map<String, Object> map, Map<String, File> fileMap) {
        MultipartBody.Builder builder = new MultipartBody.Builder();
        builder.setType(MultipartBody.FORM);
        //遍历参数
        if (map != null) {
            for (Map.Entry<String, Object> entry : map.entrySet()) {
                builder.addFormDataPart(entry.getKey(), entry.getValue().toString());
            }
        }
        //遍历文件
        for (Map.Entry<String, File> entry : fileMap.entrySet()) {
            File file = entry.getValue();
            if (!file.exists() || !file.isFile()) {
                continue;
            }
            builder.addFormDataPart(entry.getKey(), file.getName(), RequestBody.create(MEDIA_TYPE_ATTACH, file));
        }
        return builder.build();
    }
}

==> util-1.0.4-sources.jar: android/library/util/http/HttpBuildUtil.java <==
package android.library.util.http;

import android.text.TextUtils;
import okhttp3.*;

import java.io.File;
import java.util.Map;

public class HttpBuildUtil {
    private static final MediaType MEDIA_TYPE_ATTACH = MediaType.parse("application/octet-stream;charset=utf-8");
    private static final MediaType MEDIA_TYPE_JSON = MediaType.parse("application/json;charset=utf-8");

    /**
     * 构建一个Get Request
     *
     * @param r HttpBuilder
     * @return Request
     */
    public static Request createGetRequest(HttpBuilder r) {
        String getParams = TextUtils.isEmpty(r.getGetParams()) ? "" : "?".concat(r.getGetParams());
        Request.Builder builder = buildRequestBuilder(r.getHeaders(), r.getCacheControl(), r.getTag());
        return builder.url(r.getUrl().concat(getParams))
                .get()
                .build();
    }

    /**
     * 构建一个Post From Request
     *
     * @param r HttpBuilder
     * @return Request
     */
    public static Request createPostFromRequest(HttpBuilder r) {
        Request.Builder builder = buildRequestBuilder(r.getHeaders(), r.getCacheControl(), r.getTag());
        return builder.url(r.getUrl())
                .post(r.getRequestBody())
                .build();
    }

    /**
     * 构建一个Post JSON Request
     *
     * @param r HttpBuilder
     * @return Request
     */
    public static Request createPostJSONRequest(HttpBuilder r) {
        Request.Builder builder = buildRequestBuilder(r.getHeaders(), r.getCacheControl(), r.getTag());
        return builder.url(r.getUrl())
                .post(RequestBody.create(MEDIA_TYPE_JSON, r.getJsonParams()))
                .build();
    }

    /**
     * 构建一个没有设置请求方法的 Request.Builder
     *
     * @param headers      请求头
     * @param cacheControl 缓存控制
     * @param tag          tag
     * @return Request.Builder对象
     */
    public static Request.Builder buildRequestBuilder(Headers headers, CacheControl cacheControl, Object tag) {
        Request.Builder builder = new Request.Builder();
        builder.tag(tag);
        if (headers != null) {
            builder.headers(headers);
        }
        if (cacheControl != null) {
            builder.cacheControl(cacheControl);
        }
        return builder;
    }

    /**
     * 构建一个表单
     *
     * @param map map参数集合
     * @return RequestBody
     */
    public static <K, V> RequestBody buildFormRequestBody(Map<K, V> map) {
        FormBody.Builder builder = new FormBody.Builder();
        //遍历参数
        if (map != null) {
            for (Map.Entry<K, V> entry : map.entrySet()) {
                builder.add(entry.getKey().toString(), entry.getValue().toString());
            }
        }
        return builder.build();
    }

    /**
     * 构建一个表单(带文件)
     *
     * @param map     map参数集合
     * @param fileMap map文件集合
     * @return RequestBody
     */
    public static RequestBody buildFormRequestBody(Map<String, Object> map, Map<String, File> fileMap) {
        MultipartBody.Builder builder = new MultipartBody.Builder();
        builder.setType(MultipartBody.FORM);
        //遍历参数
        if (map != null) {
            for (Map.Entry<String, Object> entry : map.entrySet()) {
                builder.addFormDataPart(entry.getKey(), entry.getValue().toString());
            }
        }
        //遍历文件
        for (Map.Entry<String, File> entry : fileMap.entrySet()) {
            File file = entry.getValue();
            if (!file.exists() || !file.isFile()) {
                continue;
            }
            builder.addFormDataPart(entry.getKey(), file.getName(), RequestBody.create(MEDIA_TYPE_ATTACH, file));
        }
        return builder.build();
    }
}
